% *Copyright:
%
%    Copyright (C) 2000,2001,2002 Patrick Riley
%
%     This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%
% *EndCopyright:

%Patrick Riley <pfr@cs.cmu.edu>
%
%This is my class file for producing slides in LaTeX
% This started as quick adaptation of stuff I got Peter Stone, but I
 % have since rewritten essentially everything
% This class is designed to be used with both dvips and pdftex, and
 % should do the right thing in both cases. 
% Be sure and check out the options below

% Read the comments in the file to understand what this provides for
 % you. 

% There's also a file called pfrslides.directions which gives lots of
% pointers on how to use this stuff.

% last update: 10/14/2002

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%TODO and BUGS
%
% make a compressed itemize
% Add a macro to help include movies
% Can we use transparent graphics somehow?
% Do we need more interesting bullets? maybe use colors?
% Check out other hyperref options from foliage.sty
% use docstrip stuff?
% Can slides be rotated
% How can we get teh warning about \\ to leave?
% define \section* to \section (I really haven't been able to get
%  this to work! Grrr)
%D add \formattitle thing so Mike can change fonts easily
%D is there some way that the \multiinclude hack for ps can accept pause=?
%D do I need to add a page.-1 link for the control bar on the title page?
%D Clean up the footer graphics: I have no vector'd dragon
%D Fix the references pdf bookmark name 
%D Organize the file better!
%D fullslide macro needs to be cleaned up
%D Make default bookmark links work for repeated titles
%D set up a bit nicer stuff for highlight management (probably just set up colors)
%D What about references and bibliographies?
%D put stuff for mulit-level metapost files
%D Something is still funny with the space in the footers
%D  I should just redo all this footer stuff in a cleaner way
%D passing options to foils.cls
%D Move to use less options
%D add options to remove all pause marks.
%D do something about the pause thing moving the footer over
%D Navigation aids should advance to the next slidehead thing
%D  Make sure this does the right thing with ppower4
%D switch to using foils as the base
%D rework slide head stuff to have on/off kinds of things
%D Footers can not be turned off on a page by page basis
%D Put in navigation aids (see /usr1/pfr/tmp/foliage.sty)
%D Put rule in slidehead closer
%D move to ifthen package: \usepackage{ifthen} \newboolean{foo}
 %D \setboolean{foo}{true} \ifthenelse{\boolean{foo}}{then branch}{else branch}
%D Make two-sided thing a package error
%D logo on/off, foot string on/off, etc
%D optional rule before the footer
%D need to set the height of the slidehead box to some ``constant'' value
%D do we need to set pdfpagewidth and height? someone claims that
%D   hyperref does it
%X Put this stuff in where appropriate for some modes of postscript.
%X> \special{papersize=10.5in,8.4in}
%X> \special{! TeXDict begin /landplus90{true}store end } 
%X (letting geometry handle all this stuff)
%D be able to specialize the geometry options - switch to keyval setup?

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%NOTES TO USERS
% The file I always start with when making slides is in bare-slides.ltx 
%  (check out /afs/cs/user/pfr/tex/ if you don't have it)
% You have to run pdflatex twice to get bookmarks correctly. pdflatex
 % does *not* warn you about this
% The environment varialbe TEXPSHEADERS gives the directories which
 % pdftex searches for graphics
% This file is not well documented
% This class requires some ppower4 files, even if you don't want to
%  use PPower4. Also, You should get my modified version from 
%  /afs/cs/user/pfr/tex/pp4sty
% The effective interior size with a 1 line footer and a single line header
%  (with lines separating both) is height=5.79in,width=9in
% This used to be called myslides, but I changed the name

%Thank you to Mike Bowling (mhb@cs.cmu.edu) for testing, suggestions,
% and patches
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The header info
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{pfrslides}
          [2003/03/25 v1.2.2i Pat Riley's slide class]


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% A few packages we need at the start
\RequirePackage{ifthen}

%this sets up an if to check if we are using pdflatex or regular latex
\provideboolean{pdf}
\ifx\pdfoutput\undefined
\setboolean{pdf}{false}
\else
\setboolean{pdf}{true}
\fi
% This is the old way; I left the code here in case someone uses it
%\newif\ifpdf
%\ifx\pdfoutput\undefined
%\pdffalse
%\else
%\pdftrue
%\fi

\ifthenelse{\boolean{pdf}}{\PassOptionsToClass{pdftex}{foils}}{}

\PassOptionsToPackage{usenames}{color}
\ifthenelse{\boolean{pdf}}
{\PassOptionsToPackage{pdftex,dvipsnames}{color}}
{\PassOptionsToPackage{dvips,usenames}{color}}
\RequirePackage{color}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Some TeX definitions we need to do the option parsing correctly
% returns whether the expansion of the argument is empty
\def\ifempty#1{%
\edef\thearg{#1}%
\expandafter\ifx\expandafter\relax\thearg\relax}
\def\ifbeginswith#1#2{%
\def\ifbeginswithfn##1#1##2EOA{\ifempty{##1}}%
\edef\thearg{#2}%
\expandafter\ifbeginswithfn\thearg#1EOA}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Setting up booleans and other thingsto be set by the options
\newboolean{pfrslides@usefooter}
\newboolean{pfrslides@fontsizeset}
\setboolean{pfrslides@fontsizeset}{false}
\def\pfrslides@csfile{pfrcsWhiteRed.clo}
\def\pfrslides@optfile{}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% All the options

%This affects whether extra space is allowed for the footer
\DeclareOption{nofooter}{\setboolean{pfrslides@usefooter}{false}}
\DeclareOption{usefooter}{\setboolean{pfrslides@usefooter}{true}}

%This defines all ppower4 (\pause) stuff to have no effect
%I left this to be an option because it really need to be document wide
\DeclareOption{nopppp}{%
\PassOptionsToPackage{ignore}{pause}}

%removes all color that the package gives
\DeclareOption{monochrome}{\PassOptionsToPackage{monochrome}{color}
  \AtEndOfClass{
    \def\SlideHeadColor{}
    \def\DefaultSlideColor{}
    \def\SlideHeadRuleColor{}
    \def\emphcol{Black}
    \def\EmphCol{Black}
    \def\EMPHCOL{Black}
    \renewcommand{\colemph}[1]{#1}
    \renewcommand{\ColEmph}[1]{#1}
    \renewcommand{\COLEMPH}[1]{#1}
    \renewcommand{\coldeemph}[1]{#1}
    \renewcommand{\heademph}[1]{#1}}}
%changes the page size to better fill landscape slides
\DeclareOption{screen}{
  \ClassInfo{pfrslides}{Using 'screen' option}
  \ExecuteOptions{controlbar}
  \PassOptionsToClass{landscape}{foils}
  % I don't use the screen option to geometry because I want some more area
  \PassOptionsToPackage{papersize={11in,8.25in},scale={0.9,0.9},centering}{geometry}}
%changes the page size to better fill landscape slides
\DeclareOption{landscape}{
  \ClassInfo{pfrslides}{Using 'landscape' option}
  \ExecuteOptions{nocontrolbar}
  \PassOptionsToClass{landscape}{foils}
  \PassOptionsToPackage{landscape,scale={0.85,0.85},centering}{geometry}}
%changes the page size to better fill portrait slides
\DeclareOption{portrait}{
  \ClassInfo{pfrslides}{Using 'portrait' option}
  \ExecuteOptions{nocontrolbar}
  \PassOptionsToPackage{portrait,scale={0.85,0.85},centering}{geometry}}

% Default argument processing. Looks for args of the form 'csARG',
% 'optARG', or otherwise passes it to foils
\DeclareOption*{
  \newif\ifmatch
  \matchfalse
  \ifbeginswith{cs}{\CurrentOption}
  \global\edef\pfrslides@csfile{pfr\CurrentOption.clo}
  \matchtrue
  \fi
  \ifbeginswith{opt}{\CurrentOption}
  \global\edef\pfrslides@optfile{pfr\CurrentOption.clo}
  \matchtrue
  \fi
  \ifmatch\else\setboolean{pfrslides@fontsizeset}{true}\PassOptionsToClass{\CurrentOption}{foils}\fi}

%Provide default options
\ExecuteOptions{usefooter}

%we use * to get the options in the order the user specified them.
\ProcessOptions* 

\ifthenelse{\boolean{pfrslides@fontsizeset}}{}{\PassOptionsToClass{25pt}{foils}}

%Load the color scheme
\InputIfFileExists{\pfrslides@csfile}{}{\ClassError{pfrslides}{Could not load color
  option file \pfrslides@csfile}{When given an option not recognized, the class
  looks for a file pfr<opt>.clo and if it is found, inputs that as the
  color scheme (only one color scheme gets loaded). This defaults to
  pfrcsWhiteRed.clo.}}

%Load the option file scheme
\expandafter\ifempty{\pfrslides@optfile}\relax\else
\InputIfFileExists{\pfrslides@optfile}{}{\ClassError{pfrslides}{Could
    not load the option file \pfrslides@optfile}{Any option to the
    class which begins with 'opt' causes the class to look for a file
    called 'pfrARGUMENT.clo'. This is primarily to be use to put
    PassOptionsToPackage commands to control the arguments sent to
    packages. Note that only one option file can be given.}}
\fi

\LoadClass{foils}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load other packages
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%\RequirePackage{times}
% ... enable ISO Latin 1 input encoding
\RequirePackage[latin1]{inputenc}
%this is used in the little control bar thing
\RequirePackage{scalefnt}
%this has some bad interaction with amssymb stuff
%\RequirePackage{mathptm}

\ifthenelse{\boolean{pfrslides@usefooter}}{\PassOptionsToPackage{includefoot}{geometry}}{\PassOptionsToPackage{ignorefoot}{geometry}}

\ifthenelse{\boolean{pdf}}{
  \PassOptionsToPackage{pdftex,bookmarks}{hyperref}
  \PassOptionsToPackage{pdftex,dvipsnames}{color}
  \PassOptionsToPackage{pdftex}{graphicx}
  \PassOptionsToPackage{pdftex}{geometry}
}{
  \PassOptionsToPackage{dvips}{hyperref}
  \PassOptionsToPackage{dvips}{color}
  \PassOptionsToPackage{dvips}{geometry}}
\PassOptionsToPackage{usenames}{color}
\RequirePackage{color}
\RequirePackage{graphicx}
\RequirePackage{array}
\RequirePackage{calc}
\RequirePackage[ignorehead,heightrounded,includemp=false]{geometry}
\RequirePackage{hyperref}
\PassOptionsToPackage{T1}{fontenc}
\RequirePackage{fontenc}
%Ppower4 stuff
\ifthenelse{\boolean{pdf}}{}{\PassOptionsToPackage{ignore}{pause}}
\RequirePackage{pause}
\RequirePackage{pp4link}
\RequirePackage{background}

%This allows us to include multi-level metapost figures into our pdf files
\ifthenelse{\boolean{pdf}}{\RequirePackage{mpmulti}}{}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Main Package Code
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%This gets the right footer on the title page
\MyLogo{\pfrslides@footer}

%Indenting on slides does not make more sense
\AtBeginDocument{\setlength{\parindent}{0pt}}

%put paragraphs a bit closer together
\AtBeginDocument{\addtolength{\parskip}{-12pt}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is some stuff I like to do for pdf files
\ifthenelse{\boolean{pdf}}{
\hypersetup{
  pdfpagemode=UseOutlines,
  pdffitwindow=true,
  colorlinks=true,
  menucolor=Gray,
  linkcolor=Gray,
  citecolor=Gray,
  pageanchor=true,
  plainpages=true,
  bookmarksopen=true}}{}
%These are some options from foliage.sty that I might want to add
%                pdfhighlight={/N}
%                pagecolor=CornflowerBlue,
%                urlcolor=BlueViolet,
%                filecolor=Turquoise,
%                pdfpagetransition=Replace,
%                anchorcolor=SkyBlue,

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Stuff for multi-level metapost files
% For ps, we just redefine to what should be the whole picture
\ifthenelse{\boolean{pdf}}%
{\DeclareGraphicsRule{*}{mps}{*}{}}%
{\newboolean{pfrslides@mpgroptions}%
\setboolean{pfrslides@mpgroptions}{false}%
\define@key{mpm}{pause}[\pause]{}%
\define@key{mpm}{graphics}{\setboolean{pfrslides@mpgroptions}{true}\global\def\mpm@graphics{\string#1}}%
\newcommand{\multiinclude}[2][pause=\pause]{%
%% reset the options 
\global\def\mpm@graphics{}%
%% get the arguments
\setkeys{mpm}{#1}%
%% include the graphics
% we have to do it this way to expand \mpm@graphics before it's passed
% to \includegraphics
\edef\@mpm@do@include{\noexpand\includegraphics[\mpm@graphics]{#2}}%
\@mpm@do@include}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This sets up some stuff for highlights
\definecolor{highlight}{rgb}{.9,.5,.9}
\pausecolors{highlight}{\DeHighlightColor}{\HighlightColor}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Make sure that we print lots of levels in the pdf table of co
\setcounter{tocdepth}{10}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Used to set the page duration for full screen display
% Warning: you might have to click the auto advance button in Full
 % Screen setup even though the n seconds specified there will be ignored!
\newcommand{\pageDuration}[1]{\hypersetup{pdfpageduration={#1}}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Useful macrors for color emphasis. Controlled by cs options
\newcommand{\colemph}[1]{\textcolor{\emphcol}{#1}}
\newcommand{\ColEmph}[1]{\textcolor{\EmphCol}{#1}}
\newcommand{\COLEMPH}[1]{\textcolor{\EMPHCOL}{#1}}
\newcommand{\heademph}[1]{\textcolor{\SlideHeadColor}{#1}}
\newcommand{\coldeemph}[1]{\textcolor{\deemphcol}{#1}}

%Set the background color
\AtEndOfClass{\pagecolor{\SlideBackgroundColor}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% some simple commands for including movies, not as pdf object, but as
% an external running thing. You should redefine \moviedir as appropriate
\newcommand{\moviedir}{movies}
\newcommand{\movielink}[2][]{\href{run:\moviedir/run-#2.sh}{\includegraphics[#1]{\moviedir/#2}}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Now header and footer stuff

\newcommand{\pfrslides@hrule}{\textcolor{\SlideHeadRuleColor}{\hrule height1.5pt width\textwidth}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Footer stuff

\newboolean{pfrslides@footpic}
\newcommand{\footpic}{\relax}
\newboolean{pfrslides@footstring}
\def\pfrslides@footstring{\empty}
\setboolean{pfrslides@footstring}{false}
\newboolean{pfrslides@controlbar}
\setboolean{pfrslides@controlbar}{false}
\newboolean{pfrslides@footrule}
\setboolean{pfrslides@footrule}{true}
\newboolean{pfrslides@headrule}
\setboolean{pfrslides@headrule}{true}
\newboolean{pfrslides@headcenter}
\setboolean{pfrslides@headcenter}{true}

%So that we can use renewcommand
\newcommand\slidepagenum{}

%The size of the footer boxes
\newlength{\footentrywidth}
\setlength{\footentrywidth}{2in}

%Use this if you want foot string
\newcommand{\footstring}[1]{\pfrslides@footstringtrue\renewcommand{\pfrslides@footstring}{#1}}
%To turn off the foot string
\newcommand{\nofootstring}{\pfrslides@footstringfalse}
\newcommand{\usefootstring}{\pfrslides@footstringtrue}

\newcommand{\footpicOldCMU}{\setboolean{pfrslides@footpic}{true}
  \renewcommand{\footpic}{\includegraphics[width=1in]{mmv-newlogo}}}
%the raisebox below is a magic number I figured out experimentally to
%put the reference point of the box on the effective baseling of the picture
\newcommand{\footpicCMU}{\setboolean{pfrslides@footpic}{true}
  \renewcommand{\footpic}{\raisebox{-0.27\height}{\includegraphics[width=1.5in]{cmuwordmark-color}}}}
\newcommand{\footpicSCSDrag}{\setboolean{pfrslides@footpic}{true}
  \renewcommand{\footpic}{\includegraphics[height=1cm]{dragon-new}}}
\newcommand{\usefootpic}{\setboolean{pfrslides@footpic}{true}}
\newcommand{\nofootpic}{\setboolean{pfrslides@footpic}{false}}

\newcommand{\usepagenums}{\renewcommand{\slidepagenum}{\textcolor{\DefaultSlideColor}{\thepage}}}
\newcommand{\nopagenums}{\renewcommand\slidepagenum{}}

\newcommand{\usecontrolbar}{\setboolean{pfrslides@controlbar}{true}}
\newcommand{\nocontrolbar}{\setboolean{pfrslides@controlbar}{false}}

\newcommand{\usefootrule}{\setboolean{pfrslides@footrule}{true}}
\newcommand{\nofootrule}{\setboolean{pfrslides@footrule}{false}}

\newcommand{\useheadrule}{\setboolean{pfrslides@headrule}{true}}
\newcommand{\noheadrule}{\setboolean{pfrslides@headrule}{false}}

\newcommand{\useheadcenter}{\setboolean{pfrslides@headcenter}{true}}
\newcommand{\noheadcenter}{\setboolean{pfrslides@headcenter}{false}}

\newcommand{\pfrslides@ControlBar}{\ifthenelse{\boolean{pdf}}{
    \mbox{%
      \tiny{}\scalefont{0.7}%
      \Acrobatmenu{FirstPage}{\reflectbox{\ding{224}}}~
      %\Acrobatmenu{PrevPage}{\reflectbox{\ding{225}}}~
      %\Acrobatmenu{NextPage}{\ding{225}}~
      \addtocounter{page}{-1}%
      \hyperlink{first.\arabic{page}}{\reflectbox{\ding{218}}}~
      \hyperlink{page.\arabic{page}}{\reflectbox{\ding{225}}}~
      \addtocounter{page}{2}%
      \hyperlink{page.\arabic{page}}{\ding{225}}~
      \hyperlink{first.\arabic{page}}{\ding{218}}~
      \addtocounter{page}{-1}%
      \Acrobatmenu{LastPage}{\ding{224}}~
      \Acrobatmenu{FullScreen}{\ding{110}}~
      \Acrobatmenu{Find}{?}~
      \Acrobatmenu{Quit}{\ding{54}}}}
  {\hspace{1in}}
  }
%There is still something ``wrong'' with this. If I adjust that space,
%the control bar moves around, which it shouldn't
\newlength{\pfrslides@cbwidth}
\AtBeginDocument{%
\sbox\@tempboxa{\pfrslides@ControlBar{}}%
\setlength{\pfrslides@cbwidth}{\wd\@tempboxa}%
%we have to add this length because of some tabular weirdness
\addtolength{\pfrslides@cbwidth}{30pt}}

\AtEndOfClass{\ifthenelse{\boolean{pfrslides@usefooter}}{\pagestyle{footer}}{}}
\newbox\pfrslides@footleft
\newbox\pfrslides@footcenter
\newbox\pfrslides@footright
\newcommand{\pfrslides@footer}{%
\pause\pauselevel{=1}%
\vbox{
  \ifthenelse{\boolean{pfrslides@footrule}}{\pfrslides@hrule}{}
  \tiny 
  \setbox\pfrslides@footleft=\hbox to \footentrywidth
  {\ifthenelse{\boolean{pfrslides@footpic}}{\footpic}{\ifthenelse{\boolean{pfrslides@footstring}}{\slidepagenum}{}}\hss}
  %Set the center box
  \setbox\pfrslides@footcenter=
  \vbox{\ifthenelse{\boolean{pfrslides@controlbar}}{\hbox to \footentrywidth{\hss\pfrslides@ControlBar\hss}}{}%
\ifthenelse{\(\boolean{pfrslides@footpic}\and\boolean{pfrslides@footstring}\)\or\(\not\boolean{pfrslides@footpic}\and\not\boolean{pfrslides@footstring}\)}%
{\hbox to \footentrywidth{\hss\slidepagenum\hss}}{}}
  %Set the right box
\setbox\pfrslides@footright=\hbox to \footentrywidth
{\ifthenelse{\boolean{pfrslides@footstring}}%
{\hss\parbox[b]{\footentrywidth}{\raggedleft\textcolor{\DefaultSlideColor}{\pfrslides@footstring}}}
{\hss\ifthenelse{\boolean{pfrslides@footpic}}{\slidepagenum}{}}}    
%Now the part that actually generates the output
\noindent\hbox to \linewidth{\box\pfrslides@footleft\hss\box\pfrslides@footcenter\hss\box\pfrslides@footright}
%\noindent\hbox{\box\pfrslides@footleft\hss\box\pfrslides@footcenter\hss\box\pfrslides@footright}
}}
%Define the footer pagestyle
\newcommand{\ps@footer}{
  \renewcommand{\@oddfoot}{\pfrslides@footer}
  %PPower4 makes the link of the form first.\arabic{page} link to the
  %first page in an incrementally built set of pages.
  %We need the \hss to avoid warnings about underfull \hbox
  \renewcommand{\@oddhead}{\hypertarget{first.\arabic{page}}{}\hss}
  \renewcommand{\@evenhead}{\ClassError{pfrslides}{Don't use
      twosided with slides}{The two sided option is not compatible
      with pfrslides. Use onesided instead}}
  \renewcommand{\@evenfoot}{\ClassError{pfrslides}{Don't use
      twosided with slides}{The two sided option is not compatible
      with pfrslides. Use onesided instead}}
}
%plain should be the same as footer
\let\ps@plain=\ps@footer
%Make the empty style really empty
\renewcommand{\ps@empty}{
  \renewcommand{\@oddfoot}{}
  %PPower4 makes the link of the form first.\arabic{page} link to the
  %first page in an incrementally built set of pages.
  %We need the \hss to avoid warnings about underfull \hbox
  \renewcommand{\@oddhead}{\hypertarget{first.\arabic{page}}{}\hss}
  \renewcommand{\@evenhead}{\ClassError{pfrslides}{Don't use
      twosided with slides}{The two sided option is not compatible
      with pfrslides. Use onesided instead}}
  \renewcommand{\@evenfoot}{\ClassError{pfrslides}{Don't use
      twosided with slides}{The two sided option is not compatible
      with pfrslides. Use onesided instead}}
}

%%%%%%%%%%%%%%%%% End document hacks
% This is to avoid warnings from the control bar about the links on
% the first and last pages being non-exisitent
\AtEndDocument{\addtocounter{page}{1}%
\hypertarget{first.\arabic{page}}{}\hypertarget{page.\arabic{page}}{}%
\addtocounter{page}{-1}}
\AtBeginDocument{\ifthenelse{\boolean{pdf}}{\hypertarget{first.-1}{}\hypertarget{page.-1}{}}{}}
  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Slide Head Stuff

% This function formats the title as you want. I provde a default, but
% feel free to \renewcommand this. You want to include a \strut after
% all font and size changes! Otherise, the location of the head rule
% or the text can jump around
\newcommand{\formatslidehead}[1]{{\Large \textbf{\color{\SlideHeadColor} #1\strut}}}

%these are internal functions. The following both take these arguments
% Argument 1 is the slides boomark level
% Argument 2 is the slides target name (for linking)
% Argument 3 is the slide title
\newcommand{\pfrslides@startslide}[3]{\newpage%
\slide@startnext@hook%
\ifthenelse{\boolean{pdf}}{
  %this puts the slide name in a reasonable format for a bookmark name
  \pdfstringdef\slidename{#3}
  \ifx#2\empty 
  %We have the \arabic{page} so that slides with the same title get
  %different bookmarks
  \pdfstringdef\slidetargname{#3.\arabic{page}}
  \else
  \pdfstringdef\slidetargname{#2}
  \fi
  \pdfbookmark[#1]{\slidename}{\slidetargname}
  }{}
}
\newcommand{\pfrslides@head}[3]{%
\pfrslides@startslide{#1}{#2}{#3}%
\parbox[b]{\textwidth}{\ifthenelse{\boolean{pfrslides@headcenter}}{\centering}{} {\formatslidehead{#3}}}%
{\vspace{2pt}\tiny\ifthenelse{\boolean{pfrslides@headrule}}{\pfrslides@hrule}{\vspace{10pt}}}%
\color{\DefaultSlideColor}}

% These control the bookmarking set up
\newcounter{defaultpdfbmlevel}
\setcounter{defaultpdfbmlevel}{0}

%Here are the ones you should use
%Arg 1 (optional): the bookmark target name
%Arg 2: the slide title
\newcommand{\slidehead}[2][\empty]{\pfrslides@head{\thedefaultpdfbmlevel}{#1}{#2}}
%Arg 1 (optional): the bookmark target name
%Arg 2: the bookmark level
%Arg 3: the slide title
\newcommand{\slideheadwlevel}[3][\empty]{\pfrslides@head{#2}{#1}{#3}}

% We don't have a vfil at the end because somehow there seems to be a
% \vfil there already
% I'm not sure why we need the \mbox{} 
\newcommand{\fullslide}[1]{%
\pfrslides@startslide{\thedefaultpdfbmlevel}{#1}{#1}%
\mbox{}\vfil\begin{center}{\LARGE\textbf{#1}}\end{center}}

%%%%%%%%%%%%%Title stuff

%%This is stuff about making the title
\let\pfrslides@origauthor=\author
\renewcommand{\author}[1]{
\ifthenelse{\boolean{pdf}}{
  \let\pfrslides@tempcolor=\color
  \let\pfrslides@tempvspace=\vspace
  \let\pfrslides@tempnewline=\\
  \let\\=\relax
  \renewcommand{\color}[1]{\relax}
  \renewcommand{\vspace}[1]{\space}
  \pdfstringdef\pfrslides@tempauthor{#1}
  \hypersetup{pdfauthor=\pfrslides@tempauthor}
  \let\color=\pfrslides@tempcolor
  \let\vspace=\pfrslides@tempvspace
  \let\\=\pfrslides@tempnewline}{}
  \pfrslides@origauthor{#1}}
\let\pfrslides@origtitle=\title
\renewcommand{\title}[1]{
\ifthenelse{\boolean{pdf}}{
  \let\pfrslides@tempcolor=\color
  \let\pfrslides@tempvspace=\vspace
  \let\pfrslides@tempnewline=\\
  \renewcommand{\color}[1]{\relax}
  \renewcommand{\vspace}[1]{\ \ }
  \pdfstringdef\pfrslides@temptitle{#1}
  \hypersetup{pdftitle=\pfrslides@temptitle}
  \let\color=\pfrslides@tempcolor
  \let\vspace=\pfrslides@tempvspace
  \let\\=\pfrslides@tempnewline}{}
\pfrslides@origtitle{\textcolor{\SlideHeadColor}{#1}}}
\let\pfrslides@origdate=\date
\renewcommand{\date}[1]{\pfrslides@origdate{\textcolor{\DefaultSlideColor}{#1}}}
\let\pfrslides@origmaketitle=\maketitle
\renewcommand{\maketitle}{%
\ifthenelse{\boolean{pdf}}{\pdfbookmark[0]{Title Page}{title}}{}%
\pfrslides@origmaketitle}

%%%%%%%%%%%%%%%%% Sectioning Stuff
% This makes bookmarks for \section style command
% Thank you to Mike Bowling (mhb@cs) for this

\def\AtStartOfNextSlide{\g@addto@macro\slide@startnext@hook}
\def\slide@startnext@reset{\gdef\slide@startnext@hook{\slide@startnext@reset}}
\slide@startnext@reset

% There is a little bit of trickery going on here. PPower4 looks for a
% link of the form first.\arabic{page} in order to create a link to
% the first build of an incremental page. 
\ifthenelse{\boolean{pdf}}{
\newcommand{\pfrslides@startsection}[2]{\AtStartOfNextSlide{%
\pdfstringdef\targname{#2}\pdfbookmark[#1]{\targname}{first.\arabic{page}}
\setcounter{defaultpdfbmlevel}{#1}\addtocounter{defaultpdfbmlevel}{1}}}
\gdef\section{\pfrslides@startsection{0}}
\gdef\subsection{\pfrslides@startsection{1}}
\gdef\subsubsection{\pfrslides@startsection{2}}
}{
\gdef\section#1{}
\gdef\subsection#1{}
\gdef\subsubsection#1{}
}


%%%%%%%%%%%%%%%%% Bibliography Stuff
% This changes the heading when you do \bibliography
\gdef\refname{\protect\slidehead{References}}
% This is only for when you use the natbib style
\AtBeginDocument{\providecommand\bibsection{}\renewcommand\bibsection{\section{References}\refname}}

%%%%%%%%%%%%%%%%% Other helpful commands

\newcommand{\centerbox}[2][5in]{
\begin{center} \fbox{\parbox{#1}{\centering #2}} \end{center}}
\newcommand{\centerboxline}[1]{
\begin{center} \fbox{#1} \end{center}}

%%%%%%%%%%%%%Set up defaults
\AtEndOfClass{
\usecontrolbar
\useheadrule
\usefootrule
\usepagenums
\useheadcenter}
%footNoPic


%%%%%%%%% OLD STUFF
%\def\slidehead#1{\newpage\begin{center}\begin{tabular*}{469pt}[t]{c}
%\Huge{\parbox[c]{457pt}{\bf #1}} \\ \vspace{7pt} \\ \hline
%\end{tabular*}\end{center}\yskip}

%\def\nolineslidehead#1{\newpage\begin{center}\begin{tabular*}{469pt}[t]{c}
%\Huge{\parbox[c]{457pt}{\bf #1}} \\ \vspace{7pt} \\ 
%\end{tabular*}\end{center}\yskip}



\endinput

